This repository contains a python package used for running the
Selenium tests for `wed <https://github.com/mangalam-research/wed>`_.

Use 0.21.0 for wed 0.30.0 and later.

Use 0.20.x for wed 0.29.x.

Use 0.19 for earlier versions of wed.
